aboutsummaryrefslogtreecommitdiff
path: root/gcc/rust/ast/rust-macro.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/rust/ast/rust-macro.h')
-rw-r--r--gcc/rust/ast/rust-macro.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/rust/ast/rust-macro.h b/gcc/rust/ast/rust-macro.h
index 1620ff6..55fbd3a 100644
--- a/gcc/rust/ast/rust-macro.h
+++ b/gcc/rust/ast/rust-macro.h
@@ -473,14 +473,14 @@ private:
/**
* Default function to use as an associated transcriber. This function should
* never be called, hence the gcc_unreachable().
* If this function is used, then the macro is not builtin and the compiler
* should make use of the actual rules. If the macro is builtin, then another
* associated transcriber should be used
*/
static Fragment dummy_builtin (Location, MacroInvocData &)
{
- gcc_unreachable ();
+ rust_unreachable ();
return Fragment::create_error ();
}
@@ -473,14 +473,14 @@ private:
/**
* Default function to use as an associated transcriber. This function should
- * never be called, hence the gcc_unreachable().
+ * never be called, hence the rust_unreachable().
* If this function is used, then the macro is not builtin and the compiler
* should make use of the actual rules. If the macro is builtin, then another